#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ILOGB_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ILOGB_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/ilogb.hpp>

#endif
